@@ -1,4 +1,6 @@
 
+let isMac = /(Mac|iPhone|iPod|iPad)/i.test(window.navigator.platform);
+
 function activateScripts(node) {
     if (node.tagName === 'SCRIPT') {
         node.parentNode.replaceChild(reScript(node), node);
@@ -71,9 +73,10 @@ class Repl {
     }
 
     $globalKDEvent(evt) {
+        let cmdctrl = isMac ? (evt.metaKey && !evt.ctrlKey) : evt.ctrlKey;
+
         // Cmd+P => focus repl
-        if (evt.metaKey && !evt.altKey && !evt.ctrlKey
-            && evt.key === "p") {
+        if (cmdctrl && !evt.altKey && evt.key === "p") {
 
             evt.preventDefault();
             evt.stopPropagation();
@@ -81,8 +84,7 @@ class Repl {
             this.editor.focus();
         }
         // Cmd+B => navigate to next visible editor
-        else if (evt.metaKey && !evt.altKey && !evt.ctrlKey
-            && evt.key === "b") {
+        else if (cmdctrl && !evt.altKey && evt.key === "b") {
 
             evt.preventDefault();
             evt.stopPropagation();
@@ -93,6 +95,10 @@ class Repl {
             .filter(container => isElementInViewport(container))
             .map(container => container.$editor);
 
+            if (!evt.shiftKey) {
+                editors.reverse();
+            }
+
             let focused = null;
             for (let editor of editors) {
                 if (focused) {
@@ -278,7 +284,7 @@ class Repl {
             let total = editor.getModel().getLineCount();
             this.multiline.set(
                 total > 1
-                || editor.getModel().getLineContent(1).match(/[\(\[\{:]$/)
+                || editor.getModel().getLineContent(1).match(/[\(\[\{:]$|^@/)
             )
         });
 
@@ -386,17 +392,17 @@ class Repl {
         return rval;
     }
 
-    read_only_editor(text) {
+    read_only_editor(text, language) {
         let elem = document.createElement("div");
         elem.style.width = this.pane.offsetWidth - 100;
 
         monaco.editor
-        .colorize(text, "python")
+        .colorize(text, language)
         .then(result => { elem.innerHTML = result; });
 
         return elem;
     }
-    
+
     send(message) {
         // Send a message back to SnekTalk
         if (this.closed) {
@@ -465,7 +471,7 @@ class Repl {
             }
         }
         else if (data.command == "echo") {
-            let ed = this.read_only_editor(data.value.trimEnd());
+            let ed = this.read_only_editor(data.value.trimEnd(), data.language || "python");
             let elem = document.createElement("div");
             elem.appendChild(ed);
             this.append(elem, "echo");
