@@ -24,14 +24,20 @@ class PrintSequence(tuple):
         )
 
 
-def snekprint(*args, **kwargs):
+def snekprint(*args, toplevel=False, file=None, std=False, **kwargs):
     builtins.print = orig_print
     sess = current_session()
     if sess is None:
         orig_print(*args, **kwargs)
     else:
-        if all(isinstance(arg, str) for arg in args):
+        if std or file is not None:
+            print(*args, file=file, **kwargs)
+            builtins.print = snekprint
+            return
+        elif all(isinstance(arg, str) for arg in args):
             html = H.div["snek-print-str"](" ".join(args))
+        elif toplevel:
+            html = hrepr(*args, **kwargs)
         else:
             html = hrepr(PrintSequence(args), **kwargs)
         sess.queue(
@@ -119,7 +125,10 @@ class SnekTalkHrepr(Hrepr):
             fr = curr.tb_frame
             code = fr.f_code
             hl = curr.tb_lineno - code.co_firstlineno
-            ed = find_fn(code, code_highlight=hl, max_height=19 * 7)
+            try:
+                ed = find_fn(code, code_highlight=hl, max_height=19 * 7)
+            except Exception as exc:
+                ed = None
             parts.append(
                 self.collapsible(
                     self.H.div["snek-title-row"](
@@ -305,7 +314,6 @@ def snekbreakpoint():
 def inject():
     builtins.help = help_placeholder
     builtins.print = snekprint
-    builtins.xprint = orig_print
     builtins.breakpoint = snekbreakpoint
     builtins.hdir = hdir
     builtins.print0 = orig_print
