@@ -1,3 +1,4 @@
+import atexit
 import errno
 import json
 import os
@@ -5,6 +6,7 @@ import random
 import socket
 import subprocess
 import threading
+import webbrowser
 
 import jurigged
 from sanic import Sanic
@@ -87,8 +89,9 @@ def _launch(slock, watch_args=None):
 
     @app.listener("after_server_start")
     async def launch_func(app, loop):
-        subprocess.run(["open", f"http://localhost:{port}/"])
+        webbrowser.open(f"http://localhost:{port}/")
 
+    atexit.register(app.stop)
     app.run(host="0.0.0.0", port=port, register_sys_signals=False)
 
 
@@ -98,7 +101,7 @@ def serve(**kwargs):
     def _start_server():
         _launch(slock, **kwargs)
 
-    thread = threading.Thread(target=_start_server, daemon=False)
+    thread = threading.Thread(target=_start_server, daemon=True)
     thread.start()
 
     sess = slock.get()
